Learn R Programming

onmaRg (version 1.0.3)

om_quint: This function converts an arbitrary vector of values into corresponding quintile scores.

Description

NA values are ignored and left NA

Usage

om_quint(x)

Value

Vector of quintile scores for each element in the input vector

Arguments

x

Vector of values to recalculate quintiles for

Details

It can be used to recalculate the quintile scores for subsets of the OnMarg dataset.

Examples

Run this code
if (FALSE) {
city_data$DEPRIVATION_Q_DA16 <- om_quint(city_data$DEPRIVATION_DA16)
}

Run the code above in your browser using DataLab