powered by
NA values are ignored and left NA
om_quint(x)
Vector of quintile scores for each element in the input vector
Vector of values to recalculate quintiles for
It can be used to recalculate the quintile scores for subsets of the OnMarg dataset.
if (FALSE) { city_data$DEPRIVATION_Q_DA16 <- om_quint(city_data$DEPRIVATION_DA16) }
Run the code above in your browser using DataLab